<?php
/**
 * CommonPlugin for phplist.
 *
 * This file is a part of CommonPlugin.
 *
 * @category  phplist
 *
 * @author    Duncan Cameron
 * @copyright 2011-2018 Duncan Cameron
 * @license   http://www.gnu.org/licenses/gpl.html GNU General Public License, Version 3
 */

/**
 * This file contains the German translation of the English text.
 */
return [
//  CommonPlugin.php
    ['phpinfo', 'phpinfo anzeigen'],
    ['config.php', 'config.php anzeigen'],
    ['php session', 'Sitzung anzeigen'],
//  Pager.php
    ['Showing %d to %d of %d', 'Zeige %d bis %d von %d'],
    ['no_results', 'Keine Ergebnisse anzuzeigen'],
//  Toolbar.php
    ['help', 'Hilfe'],
//  Widget.php
    ['Select attributes', 'Attribute auswählen'],
//  General
    ['top', 'nach oben'],
//  widget_attributeform.tpl.php
    ['Search for', 'Suche nach'],
    ['All', 'Alle'],
    ['confirmed only', 'nur bestätigte Abonnenten'],
    ['unconfirmed only', 'nur unbestätigte Abonnenten'],
    ['blacklisted only', 'nur gesperrte Abonnenten (Blacklist)'],
    ['not blacklisted only', 'nur nicht-gesperrte Abonnenten'],
//  ExportCSVAsync.php
    ['Exporting, this may take a while', 'Exporting, this may take a while'],
    ['Generating the export data', 'Generating the export data'],
    ['Exported %d of %d %d%%', 'Exported %d of %d %d%%'],
];
